@@ -391,7 +391,10 @@ def compute_sums(granularity, data, default_category, percentage_cutoff):
 
 def _csv_report(first_column, columns, sums):
     f_writer = csv.writer(
-        sys.stdout, quotechar='"', quoting=csv.QUOTE_MINIMAL, lineterminator="\n",
+        sys.stdout,
+        quotechar='"',
+        quoting=csv.QUOTE_MINIMAL,
+        lineterminator="\n",
     )
     f_writer.writerow([first_column] + columns)
     for key in sums:
@@ -400,7 +403,7 @@ def _csv_report(first_column, columns, sums):
 
 def main(config):
     """
-    Map sonar snap results to a provided list of programs and create an output that is suitable for the dashboard etc.
+    Map 'sonar probe' results to a provided list of programs and create an output that is suitable for the dashboard etc.
     """
     if config["export_csv"] is not None:
         granularity = config["export_csv"]
